Package: a4Classif
Type: Package
Title: Automated Affymetrix Array Analysis Classification Package
Version: 1.60.0
Date: 2021-07-13
Authors@R: c(
  person(given = "Willem", family = "Talloen", role = "aut"),
  person(given = "Tobias", family = "Verbeke", role = "aut", email = "tobias.verbeke@openanalytics.eu"),
  person(given = "Laure", family = "Cougnaud", role = "cre", email = "laure.cougnaud@openanalytics.eu")
 )
Description: Functionalities for classification of Affymetrix
        microarray data, integrating within the Automated Affymetrix
        Array Analysis set of packages.
Depends: a4Core, a4Preproc
Imports: methods, Biobase, ROCR, pamr, glmnet, varSelRF, utils,
        graphics, stats
Suggests: ALL, hgu95av2.db, knitr, rmarkdown
License: GPL-3
biocViews: Microarray, GeneExpression, Classification
VignetteBuilder: knitr
RoxygenNote: 7.1.1
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 12:35:22 UTC
RemoteUrl: https://github.com/bioc/a4Classif
RemoteRef: RELEASE_3_23
RemoteSha: 05b1d197dacf4c319b75cad7bbbf72287a2a4b60
NeedsCompilation: no
Packaged: 2026-04-29 18:05:53 UTC; root
Author: Willem Talloen [aut],
  Tobias Verbeke [aut],
  Laure Cougnaud [cre]
Maintainer: Laure Cougnaud <laure.cougnaud@openanalytics.eu>
Built: R 4.6.0; ; 2026-04-29 18:30:14 UTC; unix
