# Generated by roxygen2: do not edit by hand

S3method(confusionMatrix,pamClass)
S3method(plot,pamClass)
S3method(plot,rfClass)
S3method(print,topTablePam)
S3method(print,topTableRfClass)
export(ROCcurve)
export(lassoClass)
export(pamClass)
export(rfClass)
exportMethods(topTable)
importFrom(Biobase,exprs)
importFrom(Biobase,featureData)
importFrom(Biobase,featureNames)
importFrom(Biobase,pData)
importFrom(ROCR,performance)
importFrom(ROCR,plot)
importFrom(ROCR,prediction)
importFrom(a4Core,confusionMatrix)
importFrom(a4Core,topTable)
importFrom(glmnet,glmnet)
importFrom(graphics,axis)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,segments)
importFrom(methods,setMethod)
importFrom(methods,setOldClass)
importFrom(pamr,pamr.confusion)
importFrom(pamr,pamr.cv)
importFrom(pamr,pamr.listgenes)
importFrom(pamr,pamr.train)
importFrom(stats,var)
importFrom(utils,capture.output)
importFrom(utils,packageDescription)
importFrom(varSelRF,varSelRF)
